@@ -4,8 +4,6 @@ package Sidef::Deparse::Sidef {
     our @ISA = qw(Sidef);
     use Scalar::Util qw(refaddr reftype);
 
-    # This module is under development...
-
     my %addr;
 
     sub new {
@@ -54,7 +52,14 @@ package Sidef::Deparse::Sidef {
 
     sub _dump_array {
         my ($self, $array) = @_;
-        '[' . join(', ', map { $self->deparse_expr(ref($_) eq 'HASH' ? $_ : {self => $_->get_value}) } @{$array}) . ']';
+        '[' . join(
+            ', ',
+
+            ref($array) eq 'Sidef::Types::Array::Array'
+            ? (map { $self->deparse_expr({self => $_->get_value}) } @{$array})
+            : (map { $self->deparse_expr(ref($_) eq 'HASH' ? $_ : {self => $_}) } @{$array})
+          )
+          . ']';
     }
 
     sub _dump_class_name {
@@ -71,7 +76,7 @@ package Sidef::Deparse::Sidef {
         # Self obj
         my $ref = ref($obj);
         if ($ref eq 'HASH') {
-            $code = join(', ', $self->deparse_script($obj));
+            $code = join(', ', exists($obj->{self}) ? $self->deparse_expr($obj) : $self->deparse_script($obj));
             if ($self->{extra_parens}) {
                 $code = "($code)";
             }
@@ -130,10 +135,10 @@ package Sidef::Deparse::Sidef {
                 $code = "struct $obj->{__NAME__} {" . $self->_dump_vars(@vars) . '}';
             }
         }
-        elsif ($ref eq 'Sidef::Variable::InitMy') {
-            $code = "my $obj->{name}";
+        elsif ($ref eq 'Sidef::Variable::InitLocal') {
+            $code = "local $obj->{name}";
         }
-        elsif ($ref eq 'Sidef::Variable::My') {
+        elsif ($ref eq 'Sidef::Variable::Local') {
             $code = "$obj->{name}";
         }
         elsif ($ref eq 'Sidef::Variable::Init') {
@@ -238,6 +243,23 @@ package Sidef::Deparse::Sidef {
                 $code = 'return';
             }
         }
+        elsif ($ref eq 'Sidef::Module::OO') {
+            $code = "%s($obj->{module})";
+        }
+        elsif ($ref eq 'Sidef::Module::Func') {
+            $code = "%S($obj->{module})";
+        }
+        elsif ($ref eq 'Sidef::Types::Array::List') {
+            $code = join(', ', map { $self->deparse_expr({self => $_}) } @{$obj});
+        }
+        elsif ($ref eq 'Sidef::Types::Block::Gather') {
+            if (exists $addr{refaddr($obj->{block})}) {
+                $code = '';
+            }
+            else {
+                return 'gather ' . $self->deparse_expr({self => $obj->{block}});
+            }
+        }
         elsif ($ref eq 'Sidef::Math::Math') {
             $code = 'Math';
         }
@@ -318,10 +340,11 @@ package Sidef::Deparse::Sidef {
         }
         elsif ($ref eq 'Sidef::Types::Number::Number') {
             my $value = $obj->get_value;
-            $code .= ref($value) ? ref($value) eq 'Math::BigRat' ? $value->numify : $value->bstr : $value;
+            my $num = ref($value) ? ref($value) eq 'Math::BigRat' ? $value->numify : $value->bstr : $value;
+            $code = lc($num) eq 'inf' ? '0.inf' : lc($num) eq 'nan' ? '0.nan' : $num;
         }
         elsif ($ref eq 'Sidef::Types::Array::Array' or $ref eq 'Sidef::Types::Array::HCArray') {
-            $code .= $self->_dump_array($obj);
+            $code = $self->_dump_array($obj);
         }
         elsif ($obj->can('dump')) {
             $code = $obj->dump->get_value;
