@@ -47,7 +47,39 @@ package Sidef::Math::Math {
 
     sub pi {
         my ($self, $places) = @_;
-        Sidef::Types::Number::Number->new(Math::BigFloat->new(0)->bpi(defined($places) ? $places->get_value : ()));
+
+        $places = defined($places) ? $places->get_value : undef;
+
+        # For large accuracy, the arctan formulas become very inefficient with
+        # Math::BigFloat.  Switch to Brent-Salamin (aka AGM or Gauss-Legendre).
+        if (defined($places) and $places >= 1000) {
+
+            # Code by Dana Jacobsen from RosettaCode
+            # http://rosettacode.org/wiki/Arithmetic-geometric_mean/Calculate_Pi#Perl
+
+            my $acc  = $places + 8;
+            my $HALF = Math::BigFloat->new('0.5');
+
+            my $an = Math::BigFloat->bone;
+            my $bn = $HALF->copy->bsqrt($acc);
+            my $tn = $HALF->copy->bmul($HALF);
+            my $pn = Math::BigFloat->bone;
+
+            while ($pn < $acc) {
+                my $prev_an = $an->copy;
+                $an->badd($bn)->bmul($HALF, $acc);
+                $bn->bmul($prev_an)->bsqrt($acc);
+                $prev_an->bsub($an);
+                $tn->bsub($pn * $prev_an * $prev_an);
+                $pn->badd($pn);
+            }
+            $an->badd($bn);
+            $an->bmul($an, $acc)->bdiv($tn->bmul(4), $places);
+
+            return Sidef::Types::Number::Number->new($an);
+        }
+
+        Sidef::Types::Number::Number->new(Math::BigFloat->bpi(defined($places) ? $places : ()));
     }
 
     *PI = \&pi;
@@ -220,24 +252,31 @@ package Sidef::Math::Math {
     *rangeSum = \&range_sum;
 
     sub map {
+        my ($self, $value, $in_min, $in_max, $out_min, $out_max) = @_;
+
+        $value = $value->get_value;
+
+        $in_min = $in_min->get_value;
+        $in_max = $in_max->get_value;
+
+        $out_min = $out_min->get_value;
+        $out_max = $out_max->get_value;
+
+        Sidef::Types::Number::Number->new(($value - $in_min) * ($out_max - $out_min) / ($in_max - $in_min) + $out_min);
+    }
+
+    sub map_range {
         my ($self, $amount, $from, $to) = @_;
 
         $amount = $amount->get_value;
         $from   = $from->get_value;
         $to     = $to->get_value;
 
-        my $step  = ($to - $from) / $amount;
-        my $array = Sidef::Types::Array::Array->new();
-
-        return $array if $step == 0;
-
-        my @values;
-        for (my $i = $from ; $i < $to ; $i += $step) {
-            push @values, Sidef::Types::Number::Number->new($i);
-        }
-
-        $array->push(@values);
-        $array;
+        Sidef::Types::Array::RangeNumber->new(
+                                              from => $from,
+                                              to   => $to,
+                                              step => ($to - $from) / $amount,
+                                             );
     }
 
     sub number_to_percentage {
