@@ -67,8 +67,8 @@ package Sidef::Object::Object {
                     return $second->contains($first);
                 }
 
-                # String ~~ Range
-                if ($s_type eq 'Sidef::Types::Array::Range') {
+                # String ~~ RangeString
+                if ($s_type eq 'Sidef::Types::Array::RangeString') {
                     return $second->contains($first);
                 }
 
@@ -91,8 +91,8 @@ package Sidef::Object::Object {
             # First is Number
             if ($f_type eq 'Sidef::Types::Number::Number') {
 
-                # Number ~~ Range
-                if ($s_type eq 'Sidef::Types::Array::Range') {
+                # Number ~~ RangeNumber
+                if ($s_type eq 'Sidef::Types::Array::RangeNumber') {
                     return $second->contains($first);
                 }
             }
