@@ -54,6 +54,8 @@ package Sidef::Types::Block::Code {
         Storable::dclone($self);
     }
 
+    *closure = \&copy;
+
     {
         no strict 'refs';
         *{__PACKAGE__ . '::' . '*'} = \&repeat;
@@ -252,10 +254,6 @@ package Sidef::Types::Block::Code {
                 }
             }
 
-            foreach my $key (keys %named_vars) {
-                warn "[WARN] No such named argument: '$key'\n";
-            }
-
             $last == 0
               ? @{$self->{init_vars}}
               : @{$self->{init_vars}}[0 .. $last - 1];
@@ -360,18 +358,14 @@ package Sidef::Types::Block::Code {
     sub fork {
         my ($self) = @_;
 
-        state $x = do {
-            require Storable;
-            require File::Temp;
-        };
-
-        my ($fh, $filename) = File::Temp::tempfile(SUFFIX => '.rst');
-        my $fork = Sidef::Types::Block::Fork->new(result => $filename);
+        state $x = require Storable;
+        open(my $fh, '+>', undef);    # an anonymous temporary file
+        my $fork = Sidef::Types::Block::Fork->new(fh => $fh);
 
         my $pid = fork() // die "[FATAL ERROR]: cannot fork";
         if ($pid == 0) {
             srand();
-            Storable::store($self->run, $filename);
+            Storable::store_fd($self->run, $fh);
             exit 0;
         }
 
@@ -384,7 +378,7 @@ package Sidef::Types::Block::Code {
 
         my $fork = Sidef::Types::Block::Fork->new();
 
-        my $pid = fork() // die "[FATAL ERROR]: cannot fork";
+        my $pid = CORE::fork() // die "[FATAL ERROR]: cannot fork";
         if ($pid == 0) {
             srand();
             $self->run;
