@@ -70,6 +70,8 @@ package Sidef::Types::Number::Number {
         $self->new($self->get_value->copy->bmodpow($y->get_value, $mod->get_value));
     }
 
+    *expmod = \&modpow;
+
     sub pow {
         my ($self, $num) = @_;
         $self->new($self->get_value**$num->get_value);
@@ -85,16 +87,6 @@ package Sidef::Types::Number::Number {
         $self->new($self->get_value->copy->bdec);
     }
 
-    sub lt {
-        my ($self, $num) = @_;
-        Sidef::Types::Bool::Bool->new($self->get_value < $num->get_value);
-    }
-
-    sub gt {
-        my ($self, $num) = @_;
-        Sidef::Types::Bool::Bool->new($self->get_value > $num->get_value);
-    }
-
     sub and {
         my ($self, $num) = @_;
         $self->new($self->get_value->as_int->band($num->get_value->as_int));
@@ -134,6 +126,16 @@ package Sidef::Types::Number::Number {
         __PACKAGE__->new($self->get_value->bacmp($num->get_value));
     }
 
+    sub gt {
+        my ($self, $num) = @_;
+        Sidef::Types::Bool::Bool->new($self->get_value > $num->get_value);
+    }
+
+    sub lt {
+        my ($self, $num) = @_;
+        Sidef::Types::Bool::Bool->new($self->get_value < $num->get_value);
+    }
+
     sub ge {
         my ($self, $num) = @_;
         Sidef::Types::Bool::Bool->new($self->get_value >= $num->get_value);
@@ -208,11 +210,25 @@ package Sidef::Types::Number::Number {
 
         $step = defined($step) ? $step->get_value : 1;
 
-        my $array = Sidef::Types::Array::Array->new();
-        for (my $i = $self->get_value ; $i <= $num->get_value ; $i += $step) {
-            $array->push($self->new($i));
+        my @array;
+        my $to = $num->get_value;
+
+        if ($step == 1) {
+
+            # Unpack limit
+            $to = $to->bstr if ref($to);
+
+            foreach my $i ($self->get_value .. $to) {
+                push @array, $self->new($i);
+            }
         }
-        $array;
+        else {
+            for (my $i = $self->get_value ; $i <= $to ; $i += $step) {
+                push @array, $self->new($i);
+            }
+        }
+
+        Sidef::Types::Array::Array->new(@array);
     }
 
     *arr_to = \&array_to;
@@ -220,11 +236,15 @@ package Sidef::Types::Number::Number {
     sub array_downto {
         my ($self, $num, $step) = @_;
         $step = defined($step) ? $step->get_value : 1;
-        my $array = Sidef::Types::Array::Array->new();
-        for (my $i = $self->get_value ; $i >= $num->get_value ; $i -= $step) {
-            $array->push($self->new($i));
+
+        my @array;
+        my $downto = $num->get_value;
+
+        for (my $i = $self->get_value ; $i >= $downto ; $i -= $step) {
+            push @array, $self->new($i);
         }
-        $array;
+
+        Sidef::Types::Array::Array->new(@array);
     }
 
     *arr_downto = \&array_downto;
@@ -232,13 +252,11 @@ package Sidef::Types::Number::Number {
     sub to {
         my ($self, $num, $step) = @_;
         $step = defined($step) ? $step->get_value : 1;
-        Sidef::Types::Array::Range->new(
-                                        from      => $self->get_value,
-                                        to        => $num->get_value,
-                                        step      => $step,
-                                        type      => 'number',
-                                        direction => 'up'
-                                       );
+        Sidef::Types::Array::RangeNumber->new(
+                                              from => $self->get_value,
+                                              to   => $num->get_value,
+                                              step => $step,
+                                             );
     }
 
     *upto = \&to;
@@ -247,17 +265,24 @@ package Sidef::Types::Number::Number {
     sub downto {
         my ($self, $num, $step) = @_;
         $step = defined($step) ? $step->get_value : 1;
-        Sidef::Types::Array::Range->new(
-                                        from      => $self->get_value,
-                                        to        => $num->get_value,
-                                        step      => $step,
-                                        type      => 'number',
-                                        direction => 'down'
-                                       );
+        Sidef::Types::Array::RangeNumber->new(
+                                              from => $self->get_value,
+                                              to   => $num->get_value,
+                                              step => -$step,
+                                             );
     }
 
     *downTo = \&downto;
 
+    sub range {
+        my ($self, $to) = @_;
+
+        defined($to)
+          ? $self->to($to)
+          : $self->new(0)->to($self);
+
+    }
+
     sub sqrt {
         my ($self) = @_;
         $self->new(CORE::sqrt($self->get_value));
@@ -339,6 +364,11 @@ package Sidef::Types::Number::Number {
         $self->new($self->get_value->copy->blog(defined($base) ? $base->get_value : ()));
     }
 
+    sub ln {
+        my ($self) = @_;
+        $self->new($self->get_value->copy->blog);
+    }
+
     sub log10 {
         my ($self) = @_;
         $self->new($self->get_value->copy->blog(10));
@@ -421,15 +451,6 @@ package Sidef::Types::Number::Number {
     *isPos      = \&is_positive;
     *is_pos     = \&is_positive;
 
-    sub is_inf {
-        my ($self) = @_;
-        Sidef::Types::Bool::Bool->new($self->get_value->is_inf);
-    }
-
-    *isInf       = \&is_inf;
-    *is_infinite = \&is_inf;
-    *isInfinite  = \&is_inf;
-
     sub is_negative {
         my ($self) = @_;
         Sidef::Types::Bool::Bool->new($self->get_value->is_neg);
@@ -453,6 +474,15 @@ package Sidef::Types::Number::Number {
 
     *isOdd = \&is_odd;
 
+    sub is_inf {
+        my ($self) = @_;
+        Sidef::Types::Bool::Bool->new($self->get_value->is_inf);
+    }
+
+    *isInf       = \&is_inf;
+    *is_infinite = \&is_inf;
+    *isInfinite  = \&is_inf;
+
     sub is_integer {
         my ($self) = @_;
         Sidef::Types::Bool::Bool->new($self->get_value->is_int);
@@ -504,11 +534,6 @@ package Sidef::Types::Number::Number {
     *fround = \&roundf;
     *fRound = \&roundf;
 
-    sub range {
-        my ($self) = @_;
-        $self->get_value >= 0 ? $self->new(0)->to($self) : $self->to($self->new(0));
-    }
-
     sub length {
         my ($self) = @_;
         $self->new($self->get_value->length);
@@ -526,6 +551,8 @@ package Sidef::Types::Number::Number {
         $self->new($self->get_value->as_int->bnok($k->get_value));
     }
 
+    *binomial = \&nok;
+
     sub of {
         my ($self, $obj) = @_;
 
@@ -544,7 +571,7 @@ package Sidef::Types::Number::Number {
     sub to_bin {
         my ($self) = @_;
         state $x = require Math::BigInt;
-        Sidef::Types::String::String->new(Math::BigInt->new($self->get_value)->as_bin);
+        Sidef::Types::String::String->new(substr(Math::BigInt->new($self->get_value)->as_bin, 2));
     }
 
     *as_bin = \&to_bin;
@@ -552,7 +579,7 @@ package Sidef::Types::Number::Number {
     sub to_oct {
         my ($self) = @_;
         state $x = require Math::BigInt;
-        Sidef::Types::String::String->new(Math::BigInt->new($self->get_value)->as_oct);
+        Sidef::Types::String::String->new(substr(Math::BigInt->new($self->get_value)->as_oct, 1));
     }
 
     *as_oct = \&to_oct;
@@ -560,19 +587,23 @@ package Sidef::Types::Number::Number {
     sub to_hex {
         my ($self) = @_;
         state $x = require Math::BigInt;
-        Sidef::Types::String::String->new(Math::BigInt->new($self->get_value)->as_hex);
+        Sidef::Types::String::String->new(substr(Math::BigInt->new($self->get_value)->as_hex, 2));
     }
 
     *as_hex = \&to_hex;
 
     sub is_div {
         my ($self, $num) = @_;
-
         Sidef::Types::Bool::Bool->new($self->get_value % $num->get_value == 0);
     }
 
     *isDiv = \&is_div;
 
+    sub divides {
+        my ($self, $num) = @_;
+        Sidef::Types::Bool::Bool->new($num->get_value % $self->get_value == 0);
+    }
+
     sub commify {
         my ($self) = @_;
 
@@ -612,7 +643,6 @@ package Sidef::Types::Number::Number {
 
     sub shift_right {
         my ($self, $num, $base) = @_;
-
         $self->new($self->get_value->copy->brsft($num->get_value, (defined($base) ? $base->get_value : ())));
     }
 
