@@ -172,32 +172,30 @@ package Sidef::Types::String::String {
 
     sub to {
         my ($self, $string) = @_;
-        Sidef::Types::Array::Range->new(
-                                        from      => $self->get_value,
-                                        to        => $string->get_value,
-                                        type      => 'string',
-                                        direction => 'up'
-                                       );
+        Sidef::Types::Array::RangeString->new(
+                                              from => $self->get_value,
+                                              to   => $string->get_value,
+                                              asc  => 1,
+                                             );
     }
 
-    *upto = \&to;
-    *upTo = \&to;
+    *upto  = \&to;
+    *upTo  = \&to;
+    *range = \&to;
 
     sub downto {
         my ($self, $string) = @_;
-        Sidef::Types::Array::Range->new(
-                                        from      => $self->get_value,
-                                        to        => $string->get_value,
-                                        type      => 'string',
-                                        direction => 'down'
-                                       );
+        Sidef::Types::Array::RangeString->new(
+                                              from => $self->get_value,
+                                              to   => $string->get_value,
+                                              asc  => 0,
+                                             );
     }
 
     *downTo = \&downto;
 
     sub cmp {
         my ($self, $string) = @_;
-
         Sidef::Types::Number::Number->new($self->get_value cmp $string->get_value);
     }
 
@@ -880,7 +878,7 @@ package Sidef::Types::String::String {
         eval { require(($name . '.pm') =~ s{::}{/}gr) };
 
         if ($@) {
-            die substr($@, 0, rindex($@, ' at ')), "\n";
+            CORE::die CORE::substr($@, 0, CORE::rindex($@, ' at ')), "\n";
         }
 
         $name;
