@@ -34,9 +34,9 @@ my %ignored_methods = (
                        'Sidef::Types::Block::Break'     => [qw(new)],
                        'Sidef::Variable::Variable'      => [qw(set_value is_defined get_type get_value new)],
                        'Sidef::Variable::Ref'           => [qw(get_var new)],
-                       'Sidef::Variable::My'            => [qw(new)],
+                       'Sidef::Variable::Local'         => [qw(new)],
                        'Sidef::Variable::Init'          => [qw(new)],
-                       'Sidef::Variable::InitMy'        => [qw(new)],
+                       'Sidef::Variable::InitLocal'     => [qw(new)],
                        'Sidef::Sys::Sys'                => [qw(new)],
                        'Sidef::Math::Math'              => [qw(new)],
                        'Sidef::Time::Localtime'         => [qw(new)],
